@@ -36,29 +36,57 @@ public:
     QList<Akonadi::Item::Id> alreadyIndexed;
     QList<Akonadi::Item::Id> itemsRemoved;
 
-    void commit() override {}
-    bool createIndexers() override {
+    void commit() override
+    {
+    }
+
+    bool createIndexers() override
+    {
         return true;
     }
-    void findIndexed(QSet< Akonadi::Item::Id> &indexed, Akonadi::Collection::Id) override {
+
+    void findIndexed(QSet< Akonadi::Item::Id> &indexed, Akonadi::Collection::Id) override
+    {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         indexed = alreadyIndexed.toSet();
+#else
+        indexed = QSet< Akonadi::Item::Id>(alreadyIndexed.begin(), alreadyIndexed.end());
+#endif
     }
-    void index(const Akonadi::Item &item) override {
+
+    void index(const Akonadi::Item &item) override
+    {
         itemsIndexed << item.id();
     }
-    qlonglong indexedItems(Akonadi::Collection::Id) override {
+
+    qlonglong indexedItems(Akonadi::Collection::Id) override
+    {
         return alreadyIndexed.size();
     }
-    void move(const Akonadi::Item::List & /* items */,
-              const Akonadi::Collection & /* from */,
-              const Akonadi::Collection & /* to */) override {}
-    void remove(const Akonadi::Collection & /* col */) override {}
-    void remove(const QSet<Akonadi::Item::Id> &ids, const QStringList & /* mimeTypes */) override {
-        itemsRemoved += ids.toList();
+
+    void move(const Akonadi::Item::List & /* items */, const Akonadi::Collection & /* from */, const Akonadi::Collection & /* to */) override
+    {
     }
-    void remove(const Akonadi::Item::List & /* items */) override {}
-    void removeDatabase() override {}
-    bool haveIndexerForMimeTypes(const QStringList &) override {
+
+    void remove(const Akonadi::Collection & /* col */) override
+    {
+    }
+
+    void remove(const QSet<Akonadi::Item::Id> &ids, const QStringList & /* mimeTypes */) override
+    {
+        itemsRemoved += ids.values();
+    }
+
+    void remove(const Akonadi::Item::List & /* items */) override
+    {
+    }
+
+    void removeDatabase() override
+    {
+    }
+
+    bool haveIndexerForMimeTypes(const QStringList &) override
+    {
         return true;
     }
 };
@@ -138,7 +166,6 @@ private Q_SLOTS:
         QCOMPARE(index.itemsIndexed.size(), 3);
         QCOMPARE(index.itemsRemoved.size(), 3);
     }
-
 };
 
 QTEST_MAIN(CollectionIndexingJobTest)
