@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,9 +49,7 @@ public:
 
     void remove(const Akonadi::Item &item) override;
     void remove(const Akonadi::Collection &collection) override;
-    void move(Akonadi::Item::Id itemId,
-              Akonadi::Collection::Id from,
-              Akonadi::Collection::Id to) override;
+    void move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from, Akonadi::Collection::Id to) override;
 private:
     void indexEventItem(const Akonadi::Item &item, const KCalendarCore::Event::Ptr &event);
     void indexJournalItem(const Akonadi::Item &item, const KCalendarCore::Journal::Ptr &journal);
