@@ -218,21 +218,21 @@ private Q_SLOTS:
             item.setPayload(msg);
             item.setParentCollection(Akonadi::Collection(2));
             item.setFlags(Akonadi::Item::Flags() << Akonadi::MessageFlags::Seen
-                          << Akonadi::MessageFlags::Deleted
-                          << Akonadi::MessageFlags::Answered
-                          << Akonadi::MessageFlags::Flagged
-                          << Akonadi::MessageFlags::HasAttachment
-                          << Akonadi::MessageFlags::HasInvitation
-                          << Akonadi::MessageFlags::Sent
+                                                 << Akonadi::MessageFlags::Deleted
+                                                 << Akonadi::MessageFlags::Answered
+                                                 << Akonadi::MessageFlags::Flagged
+                                                 << Akonadi::MessageFlags::HasAttachment
+                                                 << Akonadi::MessageFlags::HasInvitation
+                                                 << Akonadi::MessageFlags::Sent
                           //<< Akonadi::MessageFlags::Queued    //can't have Sent and Queued at the same time
-                          << Akonadi::MessageFlags::Replied
-                          << Akonadi::MessageFlags::Forwarded
-                          << Akonadi::MessageFlags::ToAct
-                          << Akonadi::MessageFlags::Watched
+                                                 << Akonadi::MessageFlags::Replied
+                                                 << Akonadi::MessageFlags::Forwarded
+                                                 << Akonadi::MessageFlags::ToAct
+                                                 << Akonadi::MessageFlags::Watched
                           //<< Akonadi::MessageFlags::Ignored   // can't have Watched and Ignored at the same time
-                          << Akonadi::MessageFlags::Encrypted
+                                                 << Akonadi::MessageFlags::Encrypted
                           /*<< Akonadi::MessageFlags::Spam*/
-                          << Akonadi::MessageFlags::Ham);
+                                                 << Akonadi::MessageFlags::Ham);
             //Spam is exclude from indexer. So we can't add it.
             emailIndexer.index(item);
         }
@@ -269,7 +269,11 @@ private Q_SLOTS:
             addressee.setFormattedName(QStringLiteral("John Doe"));
             addressee.setNickName(QStringLiteral("JD"));
             addressee.setEmails(QStringList() << QStringLiteral("john@test.com"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             addressee.setBirthday(QDateTime(QDate(2000, 01, 01)));
+#else
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01).startOfDay()));
+#endif
             Akonadi::Item item(KContacts::Addressee::mimeType());
             item.setId(100);
             item.setPayload(addressee);
@@ -281,7 +285,11 @@ private Q_SLOTS:
             addressee.setUid(QStringLiteral("uid2"));
             addressee.setName(QStringLiteral("Jane Doe"));
             addressee.setEmails(QStringList() << QStringLiteral("jane@test.com"));
-            addressee.setBirthday(QDateTime(QDate(2001, 01, 01)));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01)));
+#else
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01).startOfDay()));
+#endif
             Akonadi::Item item(KContacts::Addressee::mimeType());
             item.setId(101);
             item.setPayload(addressee);
@@ -293,7 +301,11 @@ private Q_SLOTS:
             addressee.setUid(QStringLiteral("uid2"));
             addressee.setName(QStringLiteral("Jane Doe"));
             addressee.setEmails(QStringList() << QStringLiteral("JANE@TEST.COM"));
-            addressee.setBirthday(QDateTime(QDate(2001, 01, 01)));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01)));
+#else
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01).startOfDay()));
+#endif
             Akonadi::Item item(KContacts::Addressee::mimeType());
             item.setId(102);
             item.setPayload(addressee);
@@ -305,7 +317,11 @@ private Q_SLOTS:
             addressee.setUid(QStringLiteral("abcd-efgh-1234-5678"));
             addressee.setName(QStringLiteral("Dan Vrátil"));
             addressee.setEmails({ QStringLiteral("dan@test.com") });
-            addressee.setBirthday(QDateTime(QDate(2001, 01, 01)));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01)));
+#else
+            addressee.setBirthday(QDateTime(QDate(2000, 01, 01).startOfDay()));
+#endif
             Akonadi::Item item(KContacts::Addressee::mimeType());
             item.setId(105);
             item.setPayload(addressee);
@@ -572,6 +588,7 @@ private Q_SLOTS:
             QTest::newRow("find not subject equal note3") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
     }
+
     void testNoteSearch()
     {
         resultSearch();
@@ -708,6 +725,7 @@ private Q_SLOTS:
         }
 #endif
     }
+
 #endif
     void testEmailSearch_data()
     {
@@ -1030,10 +1048,8 @@ private Q_SLOTS:
     {
         resultSearch();
     }
-
 };
 
 QTEST_GUILESS_MAIN(SearchPluginTest)
 
 #include "searchplugintest.moc"
-
