@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,15 +39,14 @@ public:
     AkonadiSearchDebugDialogPrivate()
         : mAkonadiSearchDebugWidget(nullptr)
     {
-
     }
 
     AkonadiSearchDebugWidget *mAkonadiSearchDebugWidget = nullptr;
 };
 
 AkonadiSearchDebugDialog::AkonadiSearchDebugDialog(QWidget *parent)
-    : QDialog(parent),
-      d(new Akonadi::Search::AkonadiSearchDebugDialogPrivate)
+    : QDialog(parent)
+    , d(new Akonadi::Search::AkonadiSearchDebugDialogPrivate)
 {
     //Don't translate it's just a dialog to debug
     setWindowTitle(QStringLiteral("Debug Akonadi Search"));
