@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,10 +22,8 @@
 #include <QObject>
 #include <QStringList>
 class QProcess;
-namespace Akonadi
-{
-namespace Search
-{
+namespace Akonadi {
+namespace Search {
 class AkonadiSearchDebugSearchJob : public QObject
 {
     Q_OBJECT
@@ -56,4 +54,3 @@ private:
 }
 }
 #endif // AKONADISEARCHDEBUGSEARCHJOB_H
-
