@@ -26,13 +26,9 @@
 #include "search_pim_export.h"
 #include <QByteArray>
 
-namespace Akonadi
-{
-namespace Search
-{
-namespace PIM
-{
-
+namespace Akonadi {
+namespace Search {
+namespace PIM {
 class ResultIterator;
 
 /** Query base class. */
@@ -46,7 +42,6 @@ public:
     static Query *fromJSON(const QByteArray &json);
     static QString defaultLocation(const QString &dbName);
 };
-
 }
 }
 }
